// This file is autogenerated by CMake. Do not edit.

#include <QtCore/qtsymbolmacros.h>
#include <QtQml/qqmlextensionplugin.h>


QT_DECLARE_EXTERN_RESOURCE(qmlcache_arianna_static)
QT_DECLARE_EXTERN_RESOURCE(qmake_org_kde_arianna)
QT_DECLARE_EXTERN_RESOURCE(arianna_static_raw_qml_0)
QT_DECLARE_EXTERN_RESOURCE(arianna_static_raw_res_0)
QT_DECLARE_EXTERN_RESOURCE(arianna_static_raw_qml_0_extra_qmldirs)


QT_DECLARE_EXTERN_SYMBOL_VOID(qml_register_types_org_kde_arianna)

class org_kde_ariannaPlugin : public QQmlEngineExtensionPlugin
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID QQmlEngineExtensionInterface_iid)

public:
    org_kde_ariannaPlugin(QObject *parent = nullptr) : QQmlEngineExtensionPlugin(parent)
    {

QT_KEEP_SYMBOL(qml_register_types_org_kde_arianna)
QT_KEEP_RESOURCE(qmlcache_arianna_static)
QT_KEEP_RESOURCE(qmake_org_kde_arianna)
QT_KEEP_RESOURCE(arianna_static_raw_qml_0)
QT_KEEP_RESOURCE(arianna_static_raw_res_0)
QT_KEEP_RESOURCE(arianna_static_raw_qml_0_extra_qmldirs)
    }
};



#include "arianna_staticplugin_org_kde_ariannaPlugin.moc"
