/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<booklistmodel.h>)
#  include <booklistmodel.h>
#endif
#if __has_include(<categoryentriesmodel.h>)
#  include <categoryentriesmodel.h>
#endif
#if __has_include(<clipboard.h>)
#  include <clipboard.h>
#endif
#if __has_include(<colorschemer.h>)
#  include <colorschemer.h>
#endif
#if __has_include(<config.h>)
#  include <config.h>
#endif
#if __has_include(<contentlist.h>)
#  include <contentlist.h>
#endif
#if __has_include(<contentquery.h>)
#  include <contentquery.h>
#endif
#if __has_include(<format.h>)
#  include <format.h>
#endif
#if __has_include(<navigation.h>)
#  include <navigation.h>
#endif
#if __has_include(<tableofcontentmodel.h>)
#  include <tableofcontentmodel.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_arianna()
{
    qmlRegisterModule("org.kde.arianna", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<BookListModel>("org.kde.arianna", 254);
    qmlRegisterEnum<BookListModel::Grouping>("BookListModel::Grouping");
    qmlRegisterTypesAndRevisions<CategoryEntriesModel>("org.kde.arianna", 254);
    qmlRegisterEnum<CategoryEntriesModel::Roles>("CategoryEntriesModel::Roles");
    qmlRegisterTypesAndRevisions<Clipboard>("org.kde.arianna", 254);
    qmlRegisterTypesAndRevisions<ColorSchemer>("org.kde.arianna", 254);
    qmlRegisterTypesAndRevisions<Config>("org.kde.arianna", 254);
    qmlRegisterTypesAndRevisions<ContentList>("org.kde.arianna", 254);
    qmlRegisterTypesAndRevisions<ContentQuery>("org.kde.arianna", 254);
    qmlRegisterEnum<ContentQuery::Type>("ContentQuery::Type");
    qmlRegisterTypesAndRevisions<Format>("org.kde.arianna", 254);
    qmlRegisterTypesAndRevisions<Navigation>("org.kde.arianna", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    qmlRegisterTypesAndRevisions<TableOfContentModel>("org.kde.arianna", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.arianna", 254, 254);
}

static const QQmlModuleRegistration orgkdeariannaRegistration("org.kde.arianna", qml_register_types_org_kde_arianna);
