/****************************************************************************
** Meta object code from reading C++ file 'config.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../config.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'config.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6ConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto Config::qt_create_metaobjectdata<qt_meta_tag_ZN6ConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Config",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "bookLocationsChanged",
        "",
        "defaultFontChanged",
        "usePublisherFontChanged",
        "invertChanged",
        "justifyChanged",
        "hyphenateChanged",
        "spacingChanged",
        "brightnessChanged",
        "maxWidthChanged",
        "marginChanged",
        "showProgressChanged",
        "bookLocations",
        "isBookLocationsImmutable",
        "defaultBookLocationsValue",
        "defaultFont",
        "QFont",
        "isDefaultFontImmutable",
        "defaultDefaultFontValue",
        "usePublisherFont",
        "isUsePublisherFontImmutable",
        "defaultUsePublisherFontValue",
        "invert",
        "isInvertImmutable",
        "defaultInvertValue",
        "justify",
        "isJustifyImmutable",
        "defaultJustifyValue",
        "hyphenate",
        "isHyphenateImmutable",
        "defaultHyphenateValue",
        "spacing",
        "isSpacingImmutable",
        "defaultSpacingValue",
        "brightness",
        "isBrightnessImmutable",
        "defaultBrightnessValue",
        "maxWidth",
        "isMaxWidthImmutable",
        "defaultMaxWidthValue",
        "margin",
        "isMarginImmutable",
        "defaultMarginValue",
        "showProgress",
        "isShowProgressImmutable",
        "defaultShowProgressValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bookLocationsChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultFontChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'usePublisherFontChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'invertChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'justifyChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hyphenateChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'spacingChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'brightnessChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxWidthChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'marginChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showProgressChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bookLocations'
        QtMocHelpers::PropertyData<QStringList>(17, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isBookLocationsImmutable'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBookLocationsValue'
        QtMocHelpers::PropertyData<QStringList>(19, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFont'
        QtMocHelpers::PropertyData<QFont>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'isDefaultFontImmutable'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDefaultFontValue'
        QtMocHelpers::PropertyData<QFont>(23, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'usePublisherFont'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isUsePublisherFontImmutable'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultUsePublisherFontValue'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'invert'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isInvertImmutable'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultInvertValue'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'justify'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isJustifyImmutable'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultJustifyValue'
        QtMocHelpers::PropertyData<bool>(32, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hyphenate'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isHyphenateImmutable'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultHyphenateValue'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'spacing'
        QtMocHelpers::PropertyData<double>(36, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isSpacingImmutable'
        QtMocHelpers::PropertyData<bool>(37, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSpacingValue'
        QtMocHelpers::PropertyData<double>(38, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'brightness'
        QtMocHelpers::PropertyData<double>(39, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isBrightnessImmutable'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBrightnessValue'
        QtMocHelpers::PropertyData<double>(41, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maxWidth'
        QtMocHelpers::PropertyData<int>(42, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isMaxWidthImmutable'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMaxWidthValue'
        QtMocHelpers::PropertyData<int>(44, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'margin'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isMarginImmutable'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMarginValue'
        QtMocHelpers::PropertyData<int>(47, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showProgress'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isShowProgressImmutable'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowProgressValue'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<Config, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Config::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6ConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6ConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6ConfigE_t>.metaTypes,
    nullptr
} };

void Config::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Config *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bookLocationsChanged(); break;
        case 1: _t->defaultFontChanged(); break;
        case 2: _t->usePublisherFontChanged(); break;
        case 3: _t->invertChanged(); break;
        case 4: _t->justifyChanged(); break;
        case 5: _t->hyphenateChanged(); break;
        case 6: _t->spacingChanged(); break;
        case 7: _t->brightnessChanged(); break;
        case 8: _t->maxWidthChanged(); break;
        case 9: _t->marginChanged(); break;
        case 10: _t->showProgressChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::bookLocationsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::defaultFontChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::usePublisherFontChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::invertChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::justifyChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::hyphenateChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::spacingChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::brightnessChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::maxWidthChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::marginChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Config::*)()>(_a, &Config::showProgressChanged, 10))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->bookLocations(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isBookLocationsImmutable(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->defaultBookLocationsValue(); break;
        case 3: *reinterpret_cast<QFont*>(_v) = _t->defaultFont(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isDefaultFontImmutable(); break;
        case 5: *reinterpret_cast<QFont*>(_v) = _t->defaultDefaultFontValue(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->usePublisherFont(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->isUsePublisherFontImmutable(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->defaultUsePublisherFontValue(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->invert(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->isInvertImmutable(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->defaultInvertValue(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->justify(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->isJustifyImmutable(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->defaultJustifyValue(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->hyphenate(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->isHyphenateImmutable(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->defaultHyphenateValue(); break;
        case 18: *reinterpret_cast<double*>(_v) = _t->spacing(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->isSpacingImmutable(); break;
        case 20: *reinterpret_cast<double*>(_v) = _t->defaultSpacingValue(); break;
        case 21: *reinterpret_cast<double*>(_v) = _t->brightness(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->isBrightnessImmutable(); break;
        case 23: *reinterpret_cast<double*>(_v) = _t->defaultBrightnessValue(); break;
        case 24: *reinterpret_cast<int*>(_v) = _t->maxWidth(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->isMaxWidthImmutable(); break;
        case 26: *reinterpret_cast<int*>(_v) = _t->defaultMaxWidthValue(); break;
        case 27: *reinterpret_cast<int*>(_v) = _t->margin(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->isMarginImmutable(); break;
        case 29: *reinterpret_cast<int*>(_v) = _t->defaultMarginValue(); break;
        case 30: *reinterpret_cast<bool*>(_v) = _t->showProgress(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->isShowProgressImmutable(); break;
        case 32: *reinterpret_cast<bool*>(_v) = _t->defaultShowProgressValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setBookLocations(*reinterpret_cast<QStringList*>(_v)); break;
        case 3: _t->setDefaultFont(*reinterpret_cast<QFont*>(_v)); break;
        case 6: _t->setUsePublisherFont(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setInvert(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setJustify(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setHyphenate(*reinterpret_cast<bool*>(_v)); break;
        case 18: _t->setSpacing(*reinterpret_cast<double*>(_v)); break;
        case 21: _t->setBrightness(*reinterpret_cast<double*>(_v)); break;
        case 24: _t->setMaxWidth(*reinterpret_cast<int*>(_v)); break;
        case 27: _t->setMargin(*reinterpret_cast<int*>(_v)); break;
        case 30: _t->setShowProgress(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Config::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Config::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6ConfigE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int Config::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    return _id;
}

// SIGNAL 0
void Config::bookLocationsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Config::defaultFontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Config::usePublisherFontChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Config::invertChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Config::justifyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Config::hyphenateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Config::spacingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Config::brightnessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Config::maxWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Config::marginChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Config::showProgressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}
QT_WARNING_POP
