/****************************************************************************
** Meta object code from reading C++ file 'booklistmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../arianna-26.04.2/src/booklistmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'booklistmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13BookListModelE_t {};
} // unnamed namespace

template <> constexpr inline auto BookListModel::qt_create_metaobjectdata<qt_meta_tag_ZN13BookListModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BookListModel",
        "QML.Element",
        "auto",
        "seriesCategoryModelChanged",
        "",
        "publisherCategoryModelChanged",
        "folderCategoryModelChanged",
        "cacheLoadedChanged",
        "newlyAddedCategoryModelChanged",
        "contentModelChanged",
        "keywordCategoryModelChanged",
        "authorCategoryModelChanged",
        "contentModelItemsInserted",
        "QModelIndex",
        "index",
        "first",
        "last",
        "seriesModelForEntry",
        "CategoryEntriesModel*",
        "fileName",
        "setBookData",
        "property",
        "value",
        "removeBook",
        "deleteFile",
        "knownBookFiles",
        "countChanged",
        "count",
        "contentModel",
        "ContentList*",
        "newlyAddedCategoryModel",
        "authorCategoryModel",
        "seriesCategoryModel",
        "publisherCategoryModel",
        "keywordCategoryModel",
        "folderCategoryModel",
        "cacheLoaded",
        "Grouping",
        "GroupByNone",
        "GroupByRecentlyAdded",
        "GroupByRecentlyRead",
        "GroupByTitle",
        "GroupByAuthor",
        "GroupByPublisher"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'seriesCategoryModelChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'publisherCategoryModelChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'folderCategoryModelChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cacheLoadedChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'newlyAddedCategoryModelChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'contentModelChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keywordCategoryModelChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'authorCategoryModelChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'contentModelItemsInserted'
        QtMocHelpers::SlotData<void(QModelIndex, int, int)>(12, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Method 'seriesModelForEntry'
        QtMocHelpers::MethodData<CategoryEntriesModel *(const QString &)>(17, 4, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::QString, 19 },
        }}),
        // Method 'setBookData'
        QtMocHelpers::MethodData<void(const QString &, const QString &, const QString &)>(20, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 }, { QMetaType::QString, 21 }, { QMetaType::QString, 22 },
        }}),
        // Method 'removeBook'
        QtMocHelpers::MethodData<void(const QString &, bool)>(23, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 }, { QMetaType::Bool, 24 },
        }}),
        // Method 'removeBook'
        QtMocHelpers::MethodData<void(const QString &)>(23, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
        // Method 'knownBookFiles'
        QtMocHelpers::MethodData<QStringList() const>(25, 4, QMC::AccessPublic, QMetaType::QStringList),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'count'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags, 0x70000000 | 26),
        // property 'contentModel'
        QtMocHelpers::PropertyData<ContentList*>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'newlyAddedCategoryModel'
        QtMocHelpers::PropertyData<CategoryEntriesModel*>(30, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'authorCategoryModel'
        QtMocHelpers::PropertyData<CategoryEntriesModel*>(31, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 7),
        // property 'seriesCategoryModel'
        QtMocHelpers::PropertyData<CategoryEntriesModel*>(32, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'publisherCategoryModel'
        QtMocHelpers::PropertyData<QObject*>(33, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 1),
        // property 'keywordCategoryModel'
        QtMocHelpers::PropertyData<QObject*>(34, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 6),
        // property 'folderCategoryModel'
        QtMocHelpers::PropertyData<QObject*>(35, QMetaType::QObjectStar, QMC::DefaultPropertyFlags, 2),
        // property 'cacheLoaded'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Grouping'
        QtMocHelpers::EnumData<enum Grouping>(37, 37, QMC::EnumFlags{}).add({
            {   38, Grouping::GroupByNone },
            {   39, Grouping::GroupByRecentlyAdded },
            {   40, Grouping::GroupByRecentlyRead },
            {   41, Grouping::GroupByTitle },
            {   42, Grouping::GroupByAuthor },
            {   43, Grouping::GroupByPublisher },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<BookListModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject BookListModel::staticMetaObject = { {
    QMetaObject::SuperData::link<CategoryEntriesModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13BookListModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13BookListModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13BookListModelE_t>.metaTypes,
    nullptr
} };

void BookListModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BookListModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->seriesCategoryModelChanged(); break;
        case 1: _t->publisherCategoryModelChanged(); break;
        case 2: _t->folderCategoryModelChanged(); break;
        case 3: _t->cacheLoadedChanged(); break;
        case 4: _t->newlyAddedCategoryModelChanged(); break;
        case 5: _t->contentModelChanged(); break;
        case 6: _t->keywordCategoryModelChanged(); break;
        case 7: _t->authorCategoryModelChanged(); break;
        case 8: _t->contentModelItemsInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 9: { CategoryEntriesModel* _r = _t->seriesModelForEntry((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<CategoryEntriesModel**>(_a[0]) = std::move(_r); }  break;
        case 10: _t->setBookData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 11: _t->removeBook((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 12: _t->removeBook((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: { QStringList _r = _t->knownBookFiles();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BookListModel::*)()>(_a, &BookListModel::seriesCategoryModelChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookListModel::*)()>(_a, &BookListModel::publisherCategoryModelChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookListModel::*)()>(_a, &BookListModel::folderCategoryModelChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookListModel::*)()>(_a, &BookListModel::cacheLoadedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookListModel::*)()>(_a, &BookListModel::newlyAddedCategoryModelChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookListModel::*)()>(_a, &BookListModel::contentModelChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookListModel::*)()>(_a, &BookListModel::keywordCategoryModelChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (BookListModel::*)()>(_a, &BookListModel::authorCategoryModelChanged, 7))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 4:
        case 3:
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< CategoryEntriesModel* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ContentList* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->count(); break;
        case 1: *reinterpret_cast<ContentList**>(_v) = _t->contentModel(); break;
        case 2: *reinterpret_cast<CategoryEntriesModel**>(_v) = _t->newlyAddedCategoryModel(); break;
        case 3: *reinterpret_cast<CategoryEntriesModel**>(_v) = _t->authorCategoryModel(); break;
        case 4: *reinterpret_cast<CategoryEntriesModel**>(_v) = _t->seriesCategoryModel(); break;
        case 5: *reinterpret_cast<QObject**>(_v) = _t->publisherCategoryModel(); break;
        case 6: *reinterpret_cast<QObject**>(_v) = _t->keywordCategoryModel(); break;
        case 7: *reinterpret_cast<QObject**>(_v) = _t->folderCategoryModel(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->cacheLoaded(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setContentModel(*reinterpret_cast<ContentList**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *BookListModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BookListModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13BookListModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return CategoryEntriesModel::qt_metacast(_clname);
}

int BookListModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = CategoryEntriesModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void BookListModel::seriesCategoryModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void BookListModel::publisherCategoryModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void BookListModel::folderCategoryModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void BookListModel::cacheLoadedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void BookListModel::newlyAddedCategoryModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void BookListModel::contentModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void BookListModel::keywordCategoryModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void BookListModel::authorCategoryModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
namespace CheckNotifySignalValidity_ZN13BookListModelE {
template<typename T> using has_nullary_countChanged = decltype(std::declval<T>().countChanged());
template<typename T> using has_unary_countChanged = decltype(std::declval<T>().countChanged(std::declval<int>()));
static_assert(qxp::is_detected_v<has_nullary_countChanged, BookListModel> || qxp::is_detected_v<has_unary_countChanged, BookListModel>,
              "NOTIFY signal countChanged does not exist in class (or is private in its parent)");
}
QT_WARNING_POP
